@font-face{
  font-family: 'Roboto';
  font-weight: 100;
  src: url('fonts/Roboto-Thin.ttf') format('truetype');
}

@font-face{
  font-family: 'Roboto';
  font-weight: 400;
  src: url('fonts/Roboto-Light.ttf') format('truetype');
}

@font-face{
  font-family: 'Roboto';
  font-weight: 500;
  src: url('fonts/Roboto-Regular.ttf') format('truetype');
}

@font-face{
  font-family: 'Roboto';
  font-weight: 700;
  src: url('fonts/Roboto-Bold.ttf') format('truetype');
}

@font-face{
  font-family: 'Roboto';
  font-weight: 900;
  src: url('fonts/Roboto-Black.ttf') format('truetype');
}

*{
  box-sizing: border-box;
}

html, body{
  height: 100%;
  padding: 0;
  margin: 0;
}

body{
  padding-top: 48px;
  font-family: 'Roboto';
  background: linear-gradient(#aaa, #fefefe 60px) no-repeat;
}

#content{
  display: flex;
  flex-wrap: wrap;
  flex-direction: row;
  justify-content: space-evenly;
}

main{
  width: 70%;
  max-width: 800px;
}

aside{
  width: 30%;
  margin-top: 2em;
  max-width: 800px;
  margin-bottom: 10em;
}

article{
  padding: 10px;
}

h1{
  text-align: center;
}

h2{
  margin-top: 0;
  font-weight: 100;
  font-size: 1.7em;
  text-align: center;
}

.keywords, .seached-in{
  margin: 0;
  padding: 0;
  list-style-type: none;
}

.seached-in{
  display: inline-block;
  margin-right: 10px;
}

.keywords{
  margin-bottom: 3em;
  text-align: center;
}

.keywords .title{
  color: #888;
  font-weight: 500;
}

.keywords li, .seached-in li{
  margin: 3px;
  padding: 5px;
  color: #666;
  border-radius: 3px;
  display: inline-block;
}

.keywords li:not(:first-child):not(.no-keywords), .seached-in li:not(:first-child):not(.no-data){
  font-family: monospace;
  border: 1px solid #aaa;
  box-shadow: 0 0 10px 1px #ddd;
}

.keywords .no-keywords, .seached-in .no-data{
  font-style: italic;
}

strong{
  font-weight: 500;
}

details i{
  font-weight: 400;
}

hr{
  width: 100%;
  height: 1px;
  border: none;
  margin: 30px 0;
  background: radial-gradient(#ccc, #ccc 50%, #fefefe 70%);
}

a{
  color: royalblue;
  text-decoration: none;
  transition: text-shadow 0.3s;
}

a:hover{
  text-shadow: 0 0 2px aqua;
  transition: text-shadow 0.3s;
}

summary{
  cursor: help;
}

.red-bg, .yellow-bg, .green-bg{
  padding: 3px;
  margin: 3px 0;
  color: white;
  border-radius: 3px;
  display: inline-block;
}

.red-bg{
  background-color: #e12;
}

.yellow-bg{
  background-color: #db0;
}

.green-bg{
  background-color: #2a0;
}

.list{
  list-style-type: none;
  padding: 0;
}

details > summary{
  list-style: none;
}

details > summary::-webkit-details-marker {
  display: none;
}

.list summary::before{
  content: "";
  width: 0.75em;
  height: 0.75em;
  margin-right: 0.5em;
  display: inline-block;
  vertical-align: center;
}

.list summary{
  transition: background-color 0.3s;
}

.list summary::before{
  transition: background-color 0.3s;
}

.red-list summary::before{
  background-color: tomato;
}

.yellow-list summary::before{
  background-color: #fb3;
}

.green-list summary::before{
  background-color: #3a1;
}

.grey-list summary::before{
  background-color: #999;
}

.list summary:hover, .list summary:hover::before{
  transition: background-color 0.3s;
}

.red-list summary:hover, .red-list summary:hover::before{
  background-color: #f87;
}

.yellow-list summary:hover, .yellow-list summary:hover::before{
  background-color: #fd7;
}

.green-list summary:hover, .green-list summary:hover::before{
  background-color: #af7;
}

.green-list strong{
  color: darkslategray;
}

.grey-list summary:hover, .grey-list summary:hover::before{
  background-color: #ccc;
}

.not-important{
  color: #777;
  font-size: 0.8em;
}

details > summary{
  padding: 5px;
}

details > div{
  margin: 0;
  color: #444;
  padding: 1px 10px 10px 1.5em;
}

details[open] > div{
  background-color: white;
  box-shadow: 0 0 3px 1px #aaa inset;
}

details{
  margin: 5px 0;
  transition: border 0.3s;
  border: 1px solid #fefefe;
}

details[open] > summary{
  background-color: #ddd;
}

details[open]{
  transition: border 0.3s;
  border: 1px solid #aaa;
  border-radius: 0 0 5px 5px;
}

pre{
  margin: 0;
  padding: 3px;
  font-weight: 100;
  color: #073642;
  white-space: pre-wrap;
  border-radius: 0 0 5px 5px;
  background-color: #fdf6e3;
}

/*
** Media queries : small screens
*/

@media screen and (max-width: 961px){
  main, aside{
    width: 100%;
  }

  aside{
    margin-top: 0;
  }

  aside::before{
    content: "";
    height: 1px;
    width: 100%;
    display: block;
    margin: 30px 0;
    background: radial-gradient(#ccc, #ccc 50%, #fefefe 70%);
  }

  article{
    padding: 10px;
  }
}
